@@ -360,6 +360,7 @@ func newHugoSites(cfg deps.DepsCfg, d *deps.Deps, pageTrees *pageTrees, sites []
 			data:    lazy.New(),
 			gitInfo: lazy.New(),
 		},
+		progressReporter: &progressReporter{},
 	}
 
 	// Assemble dependencies to be used in hugo.Deps.
@@ -1440,7 +1441,7 @@ const (
 )
 
 func (s *Site) renderAndWritePage(statCounter *uint64, name string, targetPath string, p *pageState, d any, templ *tplimpl.TemplInfo) error {
-	s.h.buildCounters.pageRenderCounter.Add(1)
+	s.h.onPageRender()
 	renderBuffer := bp.GetBuffer()
 	defer bp.PutBuffer(renderBuffer)
 
